@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use vars '%Config', '$VERSION';
 
-$VERSION = "5.018004";
+$VERSION = "5.020003";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,12 +56,11 @@ sub import {
     return;
 }
 
-die "Perl lib version (5.18.4) doesn't match executable '$0' version ($])"
+die "$0: Perl lib version (5.20.3) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.18.4
-    or die "Perl lib version (5.18.4) doesn't match executable '$0' version (" .
-	sprintf("v%vd",$^V) . ")";
+$^V eq 5.20.3
+    or die sprintf "%s: Perl lib version (5.20.3) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -85,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/opt/local/lib/perl5/5.18/darwin-thread-multi-2level',
+    archlibexp => '/opt/local/lib/perl5/5.20/darwin-thread-multi-2level',
     archname => 'darwin-thread-multi-2level',
     cc => '/usr/bin/cc',
     d_readlink => 'define',
@@ -97,16 +96,16 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'DYLD_LIBRARY_PATH',
-    libpth => '/opt/local/lib /usr/lib',
+    libpth => '/opt/local/lib /Library/Developer/CommandLineTools/usr/bin/../lib/clang/7.0.2/lib /Library/Developer/CommandLineTools/usr/lib /usr/lib',
     osname => 'darwin',
     osvers => '14.5.0',
     path_sep => ':',
-    privlibexp => '/opt/local/lib/perl5/5.18',
+    privlibexp => '/opt/local/lib/perl5/5.20',
     scriptdir => '/opt/local/bin',
-    sitearchexp => '/opt/local/lib/perl5/site_perl/5.18/darwin-thread-multi-2level',
-    sitelibexp => '/opt/local/lib/perl5/site_perl/5.18',
+    sitearchexp => '/opt/local/lib/perl5/site_perl/5.20/darwin-thread-multi-2level',
+    sitelibexp => '/opt/local/lib/perl5/site_perl/5.20',
     so => 'dylib',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.18.4',
+    version => '5.20.3',
 };
